@@ -1,4 +1,11 @@
+import sys
 from quasar.launcher import Launcher
 
-if __name__ == "__main__":
+
+def main():
     Launcher().launch()
+
+
+if __name__ == "__main__":
+    sys.exit(main())
+
